import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { withIntersectionObserver, withOpenToggle } from '@s-ui/hoc';
import { BASE_CLASS, CLASS_ARROW, CLASS_INNER, CLASS_TARGET, COLORS, PREFIX_PLACEMENT, PLACEMENTS } from './config';

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends(_extends({}, res), {}, (_extends2 = {}, _extends2[key] = BASE_CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var COLOR_CLASSES = createClasses(COLORS, 'Color');

var AtomTooltip = /*#__PURE__*/function (_Component) {
  _inheritsLoose(AtomTooltip, _Component);

  function AtomTooltip() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      Tooltip: null
    };
    _this.preventNonTouchEvents = false;
    _this.hasTouchEnded = false;
    _this.touchTimer = null;
    _this.onClickTarget = null;
    _this.title = null;
    _this.refTooltip = React.createRef();
    _this.refTarget = React.createRef();

    _this.handleContextMenu = function (e) {
      e.preventDefault();
      e.stopPropagation();
      return false;
    };

    _this.handleClickOutsideElement = function (e) {
      var _this$props = _this.props,
          isOpen = _this$props.isOpen,
          onToggle = _this$props.onToggle;
      var target = _this.refTarget.current;

      if (isOpen) {
        var tooltipDom = _this.refTooltip.current;
        var isOutside = tooltipDom && !tooltipDom.contains(e.target);
        var isNotTarget = target && !target.contains(e.target);
        if (isOutside && isNotTarget) onToggle(e, {
          isOpen: false
        });
      }
    };

    _this.handleTouchStart = function (e) {
      var _this$props2 = _this.props,
          longPressTime = _this$props2.longPressTime,
          onToggle = _this$props2.onToggle;
      _this.preventNonTouchEvents = true;
      _this.hasTouchEnded = false;
      clearTimeout(_this.touchTimer);
      _this.touchTimer = setTimeout(function () {
        if (!_this.hasTouchEnded) onToggle(e);
        _this.preventNonTouchEvents = false;
        _this.hasTouchEnded = false;
      }, longPressTime);
      return false;
    };

    _this.handleTouchEnd = function (e) {
      if (!_this.preventNonTouchEvents) _this.handleStopPropagation(e);
      _this.hasTouchEnded = true;
      clearTimeout(_this.touchTimer);
    };

    _this.handleStopPropagation = function (e) {
      e.preventDefault();
      e.stopPropagation();
      return false;
    };

    _this.handleToggleOnNormalTarget = function (e) {
      var type = e.type;
      var onToggle = _this.props.onToggle;
      var isValidTrigger = ['click', 'focusin', 'mouseover', 'mouseout'].includes(type);
      if (type === 'touchstart') _this.hasTouchEnded = false;
      if (type === 'touchend') _this.hasTouchEnded = true;

      if (_this.hasTouchEnded && ['focusin', 'mouseover'].includes(type)) {
        _this.handleStopPropagation(e);
      }

      if (isValidTrigger) onToggle(e);
    };

    _this.handleToggleOnCallToActionTarget = function (e) {
      var type = e.type;
      var onToggle = _this.props.onToggle;
      if (type === 'touchstart') _this.handleTouchStart(e);
      if (type === 'touchend') _this.handleTouchEnd(e);
      if (!_this.preventNonTouchEvents) onToggle(e);
    };

    _this.handleToggle = function (e) {
      if (_this.onClickTarget) _this.handleToggleOnCallToActionTarget(e);else _this.handleToggleOnNormalTarget(e);
    };

    return _this;
  }

  var _proto = AtomTooltip.prototype;

  _proto.loadAsyncReacstrap = function loadAsyncReacstrap(e) {
    var _this2 = this;

    import(
    /* webpackChunkName: "reactstrap-Tooltip" */
    'reactstrap/lib/Tooltip').then(function (module) {
      return module["default"];
    }).then(function (Tooltip) {
      _this2.setState({
        Tooltip: Tooltip
      });

      _this2.handleToggle(e);
    });
  };

  _proto.extendChildren = function extendChildren() {
    var _this3 = this;

    var children = this.props.children; // eslint-disable-line react/prop-types

    var ref = this.refTarget;
    var className = CLASS_TARGET;
    var onTouchEnd = this.handleToggle;
    var childrenOnly = React.Children.only(children);
    return React.Children.map(childrenOnly, function (child) {
      _this3.onClickTarget = child.props.onClick;
      _this3.title = child.props.title;
      return React.cloneElement(child, {
        ref: ref,
        className: className,
        onTouchEnd: onTouchEnd
      });
    });
  };

  _proto.componentDidMount = function componentDidMount() {
    var _this4 = this;

    var target = this.refTarget.current;
    this.props.innerRef(target);
    ['touchstart', 'mouseover'].forEach(function (event) {
      return target.addEventListener(event, function (e) {
        if (!_this4.state.Tooltip) _this4.loadAsyncReacstrap(e);
      });
    });
    ['click', 'touchend'].forEach(function (event) {
      return window.addEventListener(event, _this4.handleClickOutsideElement);
    });
    target.oncontextmenu = this.handleContextMenu;
    target.addEventListener('mouseover', this.disableTitle);
    target.addEventListener('mouseout', this.restoreTitle);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var _this5 = this;

    var target = this.refTarget.current;
    clearTimeout(this.touchTimer);
    ['click', 'touchend'].forEach(function (event) {
      return window.removeEventListener(event, _this5.handleClickOutsideElement);
    });
    target.removeEventListener('mouseover', this.disableTitle);
    target.removeEventListener('mouseout', this.restoreTitle);
  };

  _proto.disableTitle = function disableTitle(e) {
    this.dataset.title = this.title;
    this.title = '';
  };

  _proto.restoreTitle = function restoreTitle(e) {
    this.title = this.dataset.title;
  };

  _proto.render = function render() {
    var _this$props3 = this.props,
        autohide = _this$props3.autohide,
        color = _this$props3.color,
        HtmlContent = _this$props3.content,
        delay = _this$props3.delay,
        hideArrow = _this$props3.hideArrow,
        placement = _this$props3.placement; // eslint-disable-line react/prop-types

    var Tooltip = this.state.Tooltip;
    var target = this.refTarget.current;
    var restrictedProps = {
      autohide: autohide,
      delay: delay,
      hideArrow: hideArrow,
      placement: placement,
      target: target
    };
    var _this$props4 = this.props,
        isVisible = _this$props4.isVisible,
        isOpen = _this$props4.isOpen; // eslint-disable-line react/prop-types

    if (!isVisible && isOpen) isOpen = false;
    var classNames = cx(BASE_CLASS, color && COLOR_CLASSES[color]);
    return /*#__PURE__*/React.createElement(React.Fragment, null, this.extendChildren(), target && Tooltip && /*#__PURE__*/React.createElement(Tooltip, Object.assign({}, restrictedProps, {
      isOpen: isOpen,
      toggle: this.handleToggle // eslint-disable-line
      ,
      className: classNames,
      innerClassName: CLASS_INNER,
      arrowClassName: CLASS_ARROW,
      placementPrefix: PREFIX_PLACEMENT,
      innerRef: this.refTooltip,
      offset: "auto,4px"
    }), HtmlContent ? /*#__PURE__*/React.createElement(HtmlContent, null) : this.title));
  };

  return AtomTooltip;
}(Component);

AtomTooltip.displayName = 'AtomTooltip';
AtomTooltip.defaultProps = {
  isVisible: true,
  longPressTime: 1000
};
export default withIntersectionObserver(withOpenToggle(AtomTooltip));
export { AtomTooltip as AtomTooltipBase };
export { COLORS as atomTooltipColors };
export { PLACEMENTS as atomTooltipPlacements };